==> react-gigya-global-events-1.5.0.tgz: package/lib/helper.js <==
var ONLOGIN_EVENT = 'onLogin';
var ONLOGOUT_EVENT = 'onLogout';
var alreadyRegistered = false;
var listeners = {
  onLogin: [],
  onLogout: []
}; // Checks if global handlers had been register already, if not, registers them

var initListener = function initListener() {
  alreadyRegistered || window.gigya.accounts.addEventHandlers({
    onLogin: executeOnLogin,
    onLogout: executeOnLogout
  });
  alreadyRegistered = true;
}; // Will execute all the configured listeners for the OnLogin event


var executeOnLogin = function executeOnLogin(event) {
  return listeners.onLogin.forEach(function (listener) {
    return listener(event);
  });
}; // Will execute all the configured listeners for the OnLogout evnet


var executeOnLogout = function executeOnLogout(event) {
  return listeners.onLogout.forEach(function (listener) {
    return listener(event);
  });
}; // Subscribes a listener to a specific event


var addSubscriber = function addSubscriber(event) {
  return function (listener) {
    listeners[event].push(listener);
  };
}; // Unsubscribes a listener to a specific event


var removeSubscriber = function removeSubscriber(event) {
  return function (listener) {
    listeners[event] = listeners[event].filter(function (func) {
      return func !== listener;
    });
  };
};

var addOnLoginSubscriber = addSubscriber(ONLOGIN_EVENT);
var addOnLogoutSubscriber = addSubscriber(ONLOGIN_EVENT);
var removeOnLoginSubscriber = removeSubscriber(ONLOGIN_EVENT);
var removeOnLogoutSubscriber = removeSubscriber(ONLOGOUT_EVENT);
export { initListener, addOnLoginSubscriber, removeOnLoginSubscriber, addOnLogoutSubscriber, removeOnLogoutSubscriber };

==> react-gigya-global-events-1.7.0.tgz: package/lib/helper.js <==
var ONLOGIN_EVENT = 'onLogin';
var ONLOGOUT_EVENT = 'onLogout';
var alreadyRegistered = false;
var listeners = {
  onLogin: [],
  onLogout: []
};

// Checks if global handlers had been register already, if not, registers them
var initListener = function initListener() {
  alreadyRegistered || window.gigya.accounts.addEventHandlers({
    onLogin: executeOnLogin,
    onLogout: executeOnLogout
  });
  alreadyRegistered = true;
};

// Will execute all the configured listeners for the OnLogin event
var executeOnLogin = function executeOnLogin(event) {
  return listeners.onLogin.forEach(function (listener) {
    return listener(event);
  });
};

// Will execute all the configured listeners for the OnLogout evnet
var executeOnLogout = function executeOnLogout(event) {
  return listeners.onLogout.forEach(function (listener) {
    return listener(event);
  });
};

// Subscribes a listener to a specific event
var addSubscriber = function addSubscriber(event) {
  return function (listener) {
    listeners[event].push(listener);
  };
};

// Unsubscribes a listener to a specific event
var removeSubscriber = function removeSubscriber(event) {
  return function (listener) {
    listeners[event] = listeners[event].filter(function (func) {
      return func !== listener;
    });
  };
};
var addOnLoginSubscriber = addSubscriber(ONLOGIN_EVENT);
var addOnLogoutSubscriber = addSubscriber(ONLOGIN_EVENT);
var removeOnLoginSubscriber = removeSubscriber(ONLOGIN_EVENT);
var removeOnLogoutSubscriber = removeSubscriber(ONLOGOUT_EVENT);
export { initListener, addOnLoginSubscriber, removeOnLoginSubscriber, addOnLogoutSubscriber, removeOnLogoutSubscriber };
